Method: Rbeapi::Api::Vlans#remove_trunk_group

Defined in:
lib/rbeapi/api/vlans.rb

#remove_trunk_group(id, value) ⇒ Object

remove_trunk_group removes the specified trunk group value from the specified vlan id in the node’s configuration. If the trunk group name does not exist, this method will return success

Commands

vlan <id>
  no trunk group <value>

Since:

  • eos_version 4.13.7M



333
334
335
# File 'lib/rbeapi/api/vlans.rb', line 333

def remove_trunk_group(id, value)
  configure(["vlan #{id}", "no trunk group #{value}"])
end