Method: Rbeapi::Client::Config#reload
- Defined in:
- lib/rbeapi/client.rb
#reload(opts = {}) ⇒ Object
This method will cause the config to be loaded. The process of finding the configuration will be repeated so it is possible a different conf file could be chosen if the original file was removed or a new file added higher on the search priority list.
253 254 255 |
# File 'lib/rbeapi/client.rb', line 253 def reload(opts = {}) autoload opts end |